@@ -398,7 +398,7 @@ from ae.core import DEBUG_LEVELS                                    # type: igno
 from ae.console import ConsoleApp                                   # type: ignore
 
 
-__version__ = '0.1.37'
+__version__ = '0.1.38'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -930,7 +930,7 @@ class MainAppBase(ConsoleApp, ABC):
         return None
 
     def find_image(self, image_name: str, height: float = 32.0, light_theme: bool = True) -> Optional[RegisteredFile]:
-        """ find best fitting image in img app folder.
+        """ find best fitting image in img app folder (see also :meth:`~MainAppBase.img_file` for easier usage).
 
         :param image_name:      name of the image (file name without extension).
         :param height:          preferred height of the image/icon.
@@ -959,6 +959,18 @@ class MainAppBase(ConsoleApp, ABC):
             return self.sound_files(sound_name)
         return None
 
+    def img_file(self, image_name: str, font_size: Optional[float] = None, light_theme: Optional[bool] = None) -> str:
+        """ shortcutting :meth:`~MainAppBase.find_image` method w/o bound property for to get image file path. """
+        if font_size is None:
+            font_size = self.font_size
+        if light_theme is None:
+            light_theme = self.light_theme
+
+        img_obj = self.find_image(image_name, height=font_size, light_theme=light_theme)
+        if img_obj:
+            return img_obj.path
+        return ''
+
     def key_press_from_framework(self, modifiers: str, key: str) -> bool:
         """ dispatch key press event, coming normalized from the UI framework. """
         self.vpo(f"MainAppBase.key_press_from_framework({modifiers}+{key})")
